@@ -35,7 +35,6 @@ if TYPE_CHECKING:  # pragma: no cover
 
 # Included for versions which do not have current comment fix
 commentclose = re.compile(r'--!?>')
-commentabruptclose = re.compile(r'-?>')
 
 # Import a copy of the html.parser lib as `htmlparser` so we can monkeypatch it.
 # Users can still do `from html import parser` and get the default behavior.
@@ -48,6 +47,8 @@ sys.modules['htmlparser'] = htmlparser
 # throwing it away. When we see it, we will process it as data.
 htmlparser.starttagopen = re.compile('<[a-zA-Z]|</>')
 
+htmlparser.endtagopen = re.compile('</[a-zA-Z]?')
+
 # Monkeypatch `HTMLParser` to only accept `?>` to close Processing Instructions.
 htmlparser.piclose = re.compile(r'\?>')
 # Monkeypatch `HTMLParser` to only recognize entity references with a closing semicolon.
@@ -92,6 +93,30 @@ htmlparser.locatetagend = re.compile(r"""
 blank_line_re = re.compile(r'^([ ]*\n){2}')
 
 
+class _HTMLParser(htmlparser.HTMLParser):
+    """Handle special start and end tags."""
+
+    def parse_endtag(self, i):
+        start = self.rawdata[i:i+3]
+        c = ord(start[-1])
+        if len(start) < 3 or not (65 <= c <= 90 or 97 <= c <= 122):
+            self.handle_data(self.rawdata[i:i + 2])
+            return i + 2
+        return super().parse_endtag(i)
+
+    def parse_starttag(self, i: int) -> int:  # pragma: no cover
+        # Treat `</>` as normal data as it is not a real tag.
+        if self.rawdata[i:i + 3] == '</>':
+            self.handle_data(self.rawdata[i:i + 3])
+            return i + 3
+
+        return super().parse_starttag(i)
+
+
+# Overwrite our custom one for people like MkDocs that pull it in
+htmlparser.HTMLParser = _HTMLParser
+
+
 class HTMLExtractor(htmlparser.HTMLParser):
     """
     Extract raw HTML from text.
@@ -110,8 +135,6 @@ class HTMLExtractor(htmlparser.HTMLParser):
 
         self.lineno_start_cache = [0]
 
-        self.override_comment_update = False
-
         # This calls self.reset
         super().__init__(*args, **kwargs)
         self.md = md
@@ -273,20 +296,8 @@ class HTMLExtractor(htmlparser.HTMLParser):
 
     def handle_comment(self, data: str):
         # Check if the comment is unclosed, if so, we need to override position
-        i = self.line_offset + self.offset + len(data) + 4
-        if self.rawdata[i:i + 3] != '-->':
-            self.handle_data('<')
-            self.override_comment_update = True
-            return
         self.handle_empty_tag('<!--{}-->'.format(data), is_block=True)
 
-    def updatepos(self, i: int, j: int) -> int:
-        if self.override_comment_update:
-            self.override_comment_update = False
-            i = 0
-            j = 1
-        return super().updatepos(i, j)
-
     def handle_decl(self, data: str):
         self.handle_empty_tag('<!{}>'.format(data), is_block=True)
 
@@ -305,21 +316,19 @@ class HTMLExtractor(htmlparser.HTMLParser):
         self.handle_data('<?')
         return i + 2
 
-    if not hasattr(htmlparser, 'commentabruptclose'):
-        # Internal -- parse comment, return length or -1 if not terminated
-        # see https://html.spec.whatwg.org/multipage/parsing.html#comment-start-state
-        def parse_comment(self, i, report=True):
-            rawdata = self.rawdata
-            assert rawdata.startswith('<!--', i), 'unexpected call to parse_comment()'
-            match = commentclose.search(rawdata, i+4)
-            if not match:
-                match = commentabruptclose.match(rawdata, i+4)
-                if not match:
-                    return -1
-            if report:
-                j = match.start()
-                self.handle_comment(rawdata[i+4: j])
-            return match.end()
+    # Internal -- parse comment, return length or -1 if not terminated
+    # see https://html.spec.whatwg.org/multipage/parsing.html#comment-start-state
+    def parse_comment(self, i, report=True):
+        rawdata = self.rawdata
+        assert rawdata.startswith('<!--', i), 'unexpected call to parse_comment()'
+        match = commentclose.search(rawdata, i+4)
+        if not match:
+            self.handle_data('<')
+            return i + 1
+        if report:
+            j = match.start()
+            self.handle_comment(rawdata[i+4: j])
+        return match.end()
 
     def parse_html_declaration(self, i: int) -> int:
         if self.at_line_start() or self.intail:
